import { combineReducers, applyMiddleware, createStore  } from "redux";
import { UserReducer } from "../reducers/user.reducer";
import { SettingReducer } from "../reducers/setting.reducer";
import { rootSaga } from "../saga";
import  createSagaMiddleware  from 'redux-saga';
import { composeWithDevTools } from "redux-devtools-extension";

const sagaMiddleware = createSagaMiddleware();

export interface ApplicationState {
  user: UserState,
  setting: SettingState,
}

export interface UserState {
  name: string;
  age: number;
  gender: number;
  email: string;
}

export interface SettingState {
  backgroundColor: string;
  foregroundColor: string;
}

export const store = createStore(combineReducers({
    user: UserReducer,
    setting: SettingReducer
  }),
  composeWithDevTools(applyMiddleware(sagaMiddleware))
);

sagaMiddleware.run(rootSaga);
